@@ -40,6 +40,8 @@
 #include "monitor/rfcomm.h"
 #include "bthost.h"
 
+#define lmp_bredr_capable(bthost)     (!((bthost)->features[4] & 0x20))
+
 /* ACL handle and flags pack/unpack */
 #define acl_handle_pack(h, f)	(uint16_t)((h & 0x0fff)|(f << 12))
 #define acl_handle(h)		(h & 0x0fff)
@@ -190,6 +192,7 @@ struct rfcomm_connection_data {
 
 struct bthost {
 	uint8_t bdaddr[6];
+	uint8_t features[8];
 	bthost_send_func send_handler;
 	void *send_data;
 	struct cmd_queue cmd_q;
@@ -222,6 +225,9 @@ struct bthost *bthost_create(void)
 
 	memset(bthost, 0, sizeof(*bthost));
 
+	/* Set defaults */
+	bthost->io_capability = 0x03;
+
 	return bthost;
 }
 
@@ -445,11 +451,12 @@ void bthost_set_send_handler(struct bthost *bthost, bthost_send_func handler,
 	bthost->send_data = user_data;
 }
 
-static void queue_command(struct bthost *bthost, const void *data,
-								uint16_t len)
+static void queue_command(struct bthost *bthost, const struct iovec *iov,
+								int iovlen)
 {
 	struct cmd_queue *cmd_q = &bthost->cmd_q;
 	struct cmd *cmd;
+	int i;
 
 	cmd = malloc(sizeof(*cmd));
 	if (!cmd)
@@ -457,8 +464,10 @@ static void queue_command(struct bthost *bthost, const void *data,
 
 	memset(cmd, 0, sizeof(*cmd));
 
-	memcpy(cmd->data, data, len);
-	cmd->len = len;
+	for (i = 0; i < iovlen; i++) {
+		memcpy(cmd->data + cmd->len, iov[i].iov_base, iov[i].iov_len);
+		cmd->len += iov[i].iov_len;
+	}
 
 	if (cmd_q->tail)
 		cmd_q->tail->next = cmd;
@@ -469,45 +478,57 @@ static void queue_command(struct bthost *bthost, const void *data,
 	cmd_q->tail = cmd;
 }
 
-static void send_packet(struct bthost *bthost, const void *data, uint16_t len)
+static void send_packet(struct bthost *bthost, const struct iovec *iov,
+								int iovlen)
 {
 	if (!bthost->send_handler)
 		return;
 
-	bthost->send_handler(data, len, bthost->send_data);
+	bthost->send_handler(iov, iovlen, bthost->send_data);
+}
+
+static void send_iov(struct bthost *bthost, uint16_t handle, uint16_t cid,
+					const struct iovec *iov, int iovcnt)
+{
+	struct bt_hci_acl_hdr acl_hdr;
+	struct bt_l2cap_hdr l2_hdr;
+	uint8_t pkt = BT_H4_ACL_PKT;
+	struct iovec pdu[3 + iovcnt];
+	int i, len = 0;
+
+	for (i = 0; i < iovcnt; i++) {
+		pdu[3 + i].iov_base = iov[i].iov_base;
+		pdu[3 + i].iov_len = iov[i].iov_len;
+		len += iov[i].iov_len;
+	}
+
+	pdu[0].iov_base = &pkt;
+	pdu[0].iov_len = sizeof(pkt);
+
+	acl_hdr.handle = acl_handle_pack(handle, 0);
+	acl_hdr.dlen = cpu_to_le16(len + sizeof(l2_hdr));
+
+	pdu[1].iov_base = &acl_hdr;
+	pdu[1].iov_len = sizeof(acl_hdr);
+
+	l2_hdr.cid = cpu_to_le16(cid);
+	l2_hdr.len = cpu_to_le16(len);
+
+	pdu[2].iov_base = &l2_hdr;
+	pdu[2].iov_len = sizeof(l2_hdr);
+
+	send_packet(bthost, pdu, 3 + iovcnt);
 }
 
 static void send_acl(struct bthost *bthost, uint16_t handle, uint16_t cid,
 						const void *data, uint16_t len)
 {
-	struct bt_hci_acl_hdr *acl_hdr;
-	struct bt_l2cap_hdr *l2_hdr;
-	uint16_t pkt_len;
-	void *pkt_data;
+	struct iovec iov;
 
-	pkt_len = 1 + sizeof(*acl_hdr) + sizeof(*l2_hdr) + len;
+	iov.iov_base = (void *) data;
+	iov.iov_len = len;
 
-	pkt_data = malloc(pkt_len);
-	if (!pkt_data)
-		return;
-
-	((uint8_t *) pkt_data)[0] = BT_H4_ACL_PKT;
-
-	acl_hdr = pkt_data + 1;
-	acl_hdr->handle = acl_handle_pack(handle, 0);
-	acl_hdr->dlen = cpu_to_le16(len + sizeof(*l2_hdr));
-
-	l2_hdr = pkt_data + 1 + sizeof(*acl_hdr);
-	l2_hdr->cid = cpu_to_le16(cid);
-	l2_hdr->len = cpu_to_le16(len);
-
-	if (len > 0)
-		memcpy(pkt_data + 1 + sizeof(*acl_hdr) + sizeof(*l2_hdr),
-								data, len);
-
-	send_packet(bthost, pkt_data, pkt_len);
-
-	free(pkt_data);
+	send_iov(bthost, handle, cid, &iov, 1);
 }
 
 static uint8_t l2cap_sig_send(struct bthost *bthost, struct btconn *conn,
@@ -515,15 +536,9 @@ static uint8_t l2cap_sig_send(struct bthost *bthost, struct btconn *conn,
 					const void *data, uint16_t len)
 {
 	static uint8_t next_ident = 1;
-	struct bt_l2cap_hdr_sig *hdr;
-	uint16_t pkt_len, cid;
-	void *pkt_data;
-
-	pkt_len = sizeof(*hdr) + len;
-
-	pkt_data = malloc(pkt_len);
-	if (!pkt_data)
-		return 0;
+	struct bt_l2cap_hdr_sig hdr;
+	uint16_t cid;
+	struct iovec iov[2];
 
 	if (!ident) {
 		ident = next_ident++;
@@ -531,22 +546,27 @@ static uint8_t l2cap_sig_send(struct bthost *bthost, struct btconn *conn,
 			ident = next_ident++;
 	}
 
-	hdr = pkt_data;
-	hdr->code  = code;
-	hdr->ident = ident;
-	hdr->len   = cpu_to_le16(len);
+	hdr.code  = code;
+	hdr.ident = ident;
+	hdr.len   = cpu_to_le16(len);
 
-	if (len > 0)
-		memcpy(pkt_data + sizeof(*hdr), data, len);
+	iov[0].iov_base = &hdr;
+	iov[0].iov_len = sizeof(hdr);
 
 	if (conn->addr_type == BDADDR_BREDR)
 		cid = 0x0001;
 	else
 		cid = 0x0005;
 
-	send_acl(bthost, conn->handle, cid, pkt_data, pkt_len);
+	if (len == 0) {
+		send_iov(bthost, conn->handle, cid, iov, 1);
+		return ident;
+	}
 
-	free(pkt_data);
+	iov[1].iov_base = (void *) data;
+	iov[1].iov_len = len;
+
+	send_iov(bthost, conn->handle, cid, iov, 2);
 
 	return ident;
 }
@@ -587,6 +607,18 @@ void bthost_send_cid(struct bthost *bthost, uint16_t handle, uint16_t cid,
 	send_acl(bthost, handle, cid, data, len);
 }
 
+void bthost_send_cid_v(struct bthost *bthost, uint16_t handle, uint16_t cid,
+					const struct iovec *iov, int iovcnt)
+{
+	struct btconn *conn;
+
+	conn = bthost_find_conn(bthost, handle);
+	if (!conn)
+		return;
+
+	send_iov(bthost, handle, cid, iov, iovcnt);
+}
+
 bool bthost_l2cap_req(struct bthost *bthost, uint16_t handle, uint8_t code,
 				const void *data, uint16_t len,
 				bthost_l2cap_rsp_cb cb, void *user_data)
@@ -633,33 +665,30 @@ bool bthost_l2cap_req(struct bthost *bthost, uint16_t handle, uint8_t code,
 static void send_command(struct bthost *bthost, uint16_t opcode,
 						const void *data, uint8_t len)
 {
-	struct bt_hci_cmd_hdr *hdr;
-	uint16_t pkt_len;
-	void *pkt_data;
+	struct bt_hci_cmd_hdr hdr;
+	uint8_t pkt = BT_H4_CMD_PKT;
+	struct iovec iov[3];
 
-	pkt_len = 1 + sizeof(*hdr) + len;
+	iov[0].iov_base = &pkt;
+	iov[0].iov_len = sizeof(pkt);
 
-	pkt_data = malloc(pkt_len);
-	if (!pkt_data)
-		return;
+	hdr.opcode = cpu_to_le16(opcode);
+	hdr.plen = len;
 
-	((uint8_t *) pkt_data)[0] = BT_H4_CMD_PKT;
+	iov[1].iov_base = &hdr;
+	iov[1].iov_len = sizeof(hdr);
 
-	hdr = pkt_data + 1;
-	hdr->opcode = cpu_to_le16(opcode);
-	hdr->plen = len;
-
-	if (len > 0)
-		memcpy(pkt_data + 1 + sizeof(*hdr), data, len);
-
-	if (bthost->ncmd) {
-		send_packet(bthost, pkt_data, pkt_len);
-		bthost->ncmd--;
-	} else {
-		queue_command(bthost, pkt_data, pkt_len);
+	if (len > 0) {
+		iov[2].iov_base = (void *) data;
+		iov[2].iov_len = len;
 	}
 
-	free(pkt_data);
+	if (bthost->ncmd) {
+		send_packet(bthost, iov, len > 0 ? 3 : 2);
+		bthost->ncmd--;
+	} else {
+		queue_command(bthost, iov, len > 0 ? 3 : 2);
+	}
 }
 
 static void next_cmd(struct bthost *bthost)
@@ -667,6 +696,7 @@ static void next_cmd(struct bthost *bthost)
 	struct cmd_queue *cmd_q = &bthost->cmd_q;
 	struct cmd *cmd = cmd_q->head;
 	struct cmd *next;
+	struct iovec iov;
 
 	if (!cmd)
 		return;
@@ -676,7 +706,10 @@ static void next_cmd(struct bthost *bthost)
 	if (!bthost->ncmd)
 		return;
 
-	send_packet(bthost, cmd->data, cmd->len);
+	iov.iov_base = cmd->data;
+	iov.iov_len = cmd->len;
+
+	send_packet(bthost, &iov, 1);
 	bthost->ncmd--;
 
 	if (next)
@@ -703,6 +736,20 @@ static void read_bd_addr_complete(struct bthost *bthost, const void *data,
 	memcpy(bthost->bdaddr, ev->bdaddr, 6);
 }
 
+static void read_local_features_complete(struct bthost *bthost,
+						const void *data, uint8_t len)
+{
+	const struct bt_hci_rsp_read_local_features *ev = data;
+
+	if (len < sizeof(*ev))
+		return;
+
+	if (ev->status)
+		return;
+
+	memcpy(bthost->features, ev->features, 8);
+}
+
 static void evt_cmd_complete(struct bthost *bthost, const void *data,
 								uint8_t len)
 {
@@ -722,6 +769,9 @@ static void evt_cmd_complete(struct bthost *bthost, const void *data,
 	switch (opcode) {
 	case BT_HCI_CMD_RESET:
 		break;
+	case BT_HCI_CMD_READ_LOCAL_FEATURES:
+		read_local_features_complete(bthost, param, len - sizeof(*ev));
+		break;
 	case BT_HCI_CMD_READ_BD_ADDR:
 		read_bd_addr_complete(bthost, param, len - sizeof(*ev));
 		break;
@@ -747,6 +797,8 @@ static void evt_cmd_complete(struct bthost *bthost, const void *data,
 		break;
 	case BT_HCI_CMD_LE_LTK_REQ_NEG_REPLY:
 		break;
+	case BT_HCI_CMD_LE_SET_ADV_DATA:
+		break;
 	default:
 		printf("Unhandled cmd_complete opcode 0x%04x\n", opcode);
 		break;
@@ -964,7 +1016,13 @@ static void evt_encrypt_change(struct bthost *bthost, const void *data,
 	if (!conn)
 		return;
 
+	if (ev->status)
+		return;
+
 	conn->encr_mode = ev->encr_mode;
+
+	if (conn->smp_data)
+		smp_conn_encrypted(conn->smp_data, conn->encr_mode);
 }
 
 static void evt_io_cap_response(struct bthost *bthost, const void *data,
@@ -1224,7 +1282,7 @@ static bool l2cap_conn_req(struct bthost *bthost, struct btconn *conn,
 
 	cb_data = bthost_find_l2cap_cb_by_psm(bthost, psm);
 	if (cb_data)
-		rsp.dcid = cpu_to_le16(conn->next_cid++);
+		rsp.dcid = rsp.scid;
 	else
 		rsp.result = cpu_to_le16(0x0002); /* PSM Not Supported */
 
@@ -1700,6 +1758,39 @@ static void rfcomm_disc_recv(struct bthost *bthost, struct btconn *conn,
 	rfcomm_ua_send(bthost, conn, l2conn, 0, dlci);
 }
 
+static void rfcomm_uih_send(struct bthost *bthost, struct btconn *conn,
+				struct l2conn *l2conn, uint8_t address,
+				uint8_t type, const void *data, uint16_t len)
+{
+	struct rfcomm_hdr hdr;
+	struct rfcomm_mcc mcc;
+	uint8_t fcs;
+	struct iovec iov[4];
+
+	hdr.address = address;
+	hdr.control = RFCOMM_CTRL(RFCOMM_UIH, 0);
+	hdr.length  = RFCOMM_LEN8(sizeof(mcc) + len);
+
+	iov[0].iov_base = &hdr;
+	iov[0].iov_len = sizeof(hdr);
+
+	mcc.type = type;
+	mcc.length = RFCOMM_LEN8(len);
+
+	iov[1].iov_base = &mcc;
+	iov[1].iov_len = sizeof(mcc);
+
+	iov[2].iov_base = (void *) data;
+	iov[2].iov_len = len;
+
+	fcs = rfcomm_fcs((uint8_t *) &hdr);
+
+	iov[3].iov_base = &fcs;
+	iov[3].iov_len = sizeof(fcs);
+
+	send_iov(bthost, conn->handle, l2conn->dcid, iov, 4);
+}
+
 static void rfcomm_ua_recv(struct bthost *bthost, struct btconn *conn,
 				struct l2conn *l2conn, const void *data,
 				uint16_t len)
@@ -1708,10 +1799,7 @@ static void rfcomm_ua_recv(struct bthost *bthost, struct btconn *conn,
 	uint8_t channel;
 	struct rfcomm_connection_data *conn_data = bthost->rfcomm_conn_data;
 	uint8_t type;
-	uint8_t buf[14];
-	struct rfcomm_hdr *hdr;
-	struct rfcomm_mcc *mcc;
-	struct rfcomm_pn *pn_cmd;
+	struct rfcomm_pn pn_cmd;
 
 	if (len < sizeof(*ua_hdr))
 		return;
@@ -1734,29 +1822,15 @@ static void rfcomm_ua_recv(struct bthost *bthost, struct btconn *conn,
 
 	bthost_add_rfcomm_conn(bthost, conn, l2conn, channel);
 
-	memset(buf, 0, sizeof(buf));
+	pn_cmd.dlci = conn_data->channel * 2;
+	pn_cmd.priority = 7;
+	pn_cmd.ack_timer = 0;
+	pn_cmd.max_retrans = 0;
+	pn_cmd.mtu = 667;
+	pn_cmd.credits = 7;
 
-	hdr = (struct rfcomm_hdr *) buf;
-	mcc = (struct rfcomm_mcc *) (buf + sizeof(*hdr));
-	pn_cmd = (struct rfcomm_pn *) (buf + sizeof(*hdr) + sizeof(*mcc));
-
-	hdr->address = RFCOMM_ADDR(1, 0);
-	hdr->control = RFCOMM_CTRL(RFCOMM_UIH, 0);
-	hdr->length  = RFCOMM_LEN8(sizeof(*mcc) + sizeof(*pn_cmd));
-
-	mcc->type = RFCOMM_MCC_TYPE(1, RFCOMM_PN);
-	mcc->length = RFCOMM_LEN8(sizeof(*pn_cmd));
-
-	pn_cmd->dlci = conn_data->channel * 2;
-	pn_cmd->priority = 7;
-	pn_cmd->ack_timer = 0;
-	pn_cmd->max_retrans = 0;
-	pn_cmd->mtu = 667;
-	pn_cmd->credits = 7;
-
-	buf[sizeof(*hdr) + sizeof(*mcc) + sizeof(*pn_cmd)] = rfcomm_fcs(buf);
-
-	send_acl(bthost, conn->handle, l2conn->dcid, buf, sizeof(buf));
+	rfcomm_uih_send(bthost, conn, l2conn, RFCOMM_ADDR(1, 0),
+			RFCOMM_MCC_TYPE(1, RFCOMM_PN), &pn_cmd, sizeof(pn_cmd));
 }
 
 static void rfcomm_dm_recv(struct bthost *bthost, struct btconn *conn,
@@ -1785,34 +1859,21 @@ static void rfcomm_msc_recv(struct bthost *bthost, struct btconn *conn,
 					struct l2conn *l2conn, uint8_t cr,
 					const struct rfcomm_msc *msc)
 {
-	uint8_t buf[8];
-	struct rfcomm_hdr *hdr = (struct rfcomm_hdr *) buf;
-	struct rfcomm_mcc *mcc = (struct rfcomm_mcc *) (buf + sizeof(*hdr));
-	struct rfcomm_msc *msc_cmd = (struct rfcomm_msc *) (buf +
-								sizeof(*hdr) +
-								sizeof(*mcc));
+	struct rfcomm_msc msc_cmd;
 
-	hdr->address = RFCOMM_ADDR(0, 0);
-	hdr->control = RFCOMM_CTRL(RFCOMM_UIH, 0);
-	hdr->length  = RFCOMM_LEN8(sizeof(*mcc) + sizeof(*msc));
-	mcc->type = RFCOMM_MCC_TYPE(cr, RFCOMM_MSC);
-	mcc->length = RFCOMM_LEN8(sizeof(*msc));
+	msc_cmd.dlci = msc->dlci;
+	msc_cmd.v24_sig = msc->v24_sig;
 
-	msc_cmd->dlci = msc->dlci;
-	msc_cmd->v24_sig = msc->v24_sig;
-	buf[sizeof(*hdr) + sizeof(*mcc) + sizeof(*msc_cmd)] = rfcomm_fcs(buf);
-
-	send_acl(bthost, conn->handle, l2conn->dcid, buf, sizeof(buf));
+	rfcomm_uih_send(bthost, conn, l2conn, RFCOMM_ADDR(0, 0),
+				RFCOMM_MCC_TYPE(cr, RFCOMM_MSC), &msc_cmd,
+				sizeof(msc_cmd));
 }
 
 static void rfcomm_pn_recv(struct bthost *bthost, struct btconn *conn,
 					struct l2conn *l2conn, uint8_t cr,
 					const struct rfcomm_pn *pn)
 {
-	uint8_t buf[14];
-	struct rfcomm_hdr *hdr;
-	struct rfcomm_mcc *mcc;
-	struct rfcomm_pn *pn_cmd;
+	struct rfcomm_pn pn_cmd;
 
 	if (!cr) {
 		rfcomm_sabm_send(bthost, conn, l2conn, 1,
@@ -1820,29 +1881,16 @@ static void rfcomm_pn_recv(struct bthost *bthost, struct btconn *conn,
 		return;
 	}
 
-	hdr = (struct rfcomm_hdr *) buf;
-	mcc = (struct rfcomm_mcc *) (buf + sizeof(*hdr));
-	pn_cmd = (struct rfcomm_pn *) (buf + sizeof(*hdr) + sizeof(*mcc));
+	pn_cmd.dlci = pn->dlci;
+	pn_cmd.flow_ctrl = pn->flow_ctrl;
+	pn_cmd.priority = pn->priority;
+	pn_cmd.ack_timer = pn->ack_timer;
+	pn_cmd.max_retrans = pn->max_retrans;
+	pn_cmd.mtu = pn->mtu;
+	pn_cmd.credits = pn->credits;
 
-	memset(buf, 0, sizeof(buf));
-
-	hdr->address = RFCOMM_ADDR(1, 0);
-	hdr->control = RFCOMM_CTRL(RFCOMM_UIH, 0);
-	hdr->length  = RFCOMM_LEN8(sizeof(*mcc) + sizeof(*pn_cmd));
-
-	mcc->type = RFCOMM_MCC_TYPE(0, RFCOMM_PN);
-	mcc->length = RFCOMM_LEN8(sizeof(*pn_cmd));
-
-	pn_cmd->dlci = pn->dlci;
-	pn_cmd->priority = pn->priority;
-	pn_cmd->ack_timer = pn->ack_timer;
-	pn_cmd->max_retrans = pn->max_retrans;
-	pn_cmd->mtu = pn->mtu;
-	pn_cmd->credits = pn->credits;
-
-	buf[sizeof(*hdr) + sizeof(*mcc) + sizeof(*pn_cmd)] = rfcomm_fcs(buf);
-
-	send_acl(bthost, conn->handle, l2conn->dcid, buf, sizeof(buf));
+	rfcomm_uih_send(bthost, conn, l2conn, RFCOMM_ADDR(1, 0),
+			RFCOMM_MCC_TYPE(0, RFCOMM_PN), &pn_cmd, sizeof(pn_cmd));
 }
 
 static void rfcomm_mcc_recv(struct bthost *bthost, struct btconn *conn,
@@ -2067,12 +2115,23 @@ void bthost_hci_connect(struct bthost *bthost, const uint8_t *bdaddr,
 	}
 }
 
+void bthost_hci_disconnect(struct bthost *bthost, uint16_t handle,
+								uint8_t reason)
+{
+	struct bt_hci_cmd_disconnect disc;
+
+	disc.handle = cpu_to_le16(handle);
+	disc.reason = reason;
+
+	send_command(bthost, BT_HCI_CMD_DISCONNECT, &disc, sizeof(disc));
+}
+
 void bthost_write_scan_enable(struct bthost *bthost, uint8_t scan)
 {
 	send_command(bthost, BT_HCI_CMD_WRITE_SCAN_ENABLE, &scan, 1);
 }
 
-void bthost_set_adv_enable(struct bthost *bthost, uint8_t enable)
+void bthost_set_adv_enable(struct bthost *bthost, uint8_t enable, uint8_t flags)
 {
 	struct bt_hci_cmd_le_set_adv_parameters cp;
 
@@ -2080,6 +2139,23 @@ void bthost_set_adv_enable(struct bthost *bthost, uint8_t enable)
 	send_command(bthost, BT_HCI_CMD_LE_SET_ADV_PARAMETERS,
 							&cp, sizeof(cp));
 
+	if (flags) {
+		struct bt_hci_cmd_le_set_adv_data adv_cp;
+
+		memset(adv_cp.data, 0, 31);
+
+		adv_cp.data[0] = 0x02;	/* Field length */
+		adv_cp.data[1] = 0x01;	/* Flags */
+		adv_cp.data[2] = flags;
+
+		adv_cp.data[3] = 0x00;	/* Field terminator */
+
+		adv_cp.len = 1 + adv_cp.data[0];
+
+		send_command(bthost, BT_HCI_CMD_LE_SET_ADV_DATA, &adv_cp,
+								sizeof(adv_cp));
+	}
+
 	send_command(bthost, BT_HCI_CMD_LE_SET_ADV_ENABLE, &enable, 1);
 }
 
@@ -2102,7 +2178,7 @@ void bthost_request_auth(struct bthost *bthost, uint16_t handle)
 		cp.handle = cpu_to_le16(handle);
 		send_command(bthost, BT_HCI_CMD_AUTH_REQUESTED, &cp, sizeof(cp));
 	} else {
-		smp_pair(conn->smp_data);
+		smp_pair(conn->smp_data, bthost->io_capability, bthost->auth_req);
 	}
 }
 
@@ -2147,16 +2223,31 @@ void bthost_set_io_capability(struct bthost *bthost, uint8_t io_capability)
 	bthost->io_capability = io_capability;
 }
 
+uint8_t bthost_get_io_capability(struct bthost *bthost)
+{
+	return bthost->io_capability;
+}
+
 void bthost_set_auth_req(struct bthost *bthost, uint8_t auth_req)
 {
 	bthost->auth_req = auth_req;
 }
 
+uint8_t bthost_get_auth_req(struct bthost *bthost)
+{
+	return bthost->auth_req;
+}
+
 void bthost_set_reject_user_confirm(struct bthost *bthost, bool reject)
 {
 	bthost->reject_user_confirm = reject;
 }
 
+bool bthost_get_reject_user_confirm(struct bthost *bthost)
+{
+	return bthost->reject_user_confirm;
+}
+
 void bthost_add_rfcomm_server(struct bthost *bthost, uint8_t channel,
 				bthost_rfcomm_connect_cb func, void *user_data)
 {
@@ -2185,6 +2276,7 @@ void bthost_start(struct bthost *bthost)
 
 	send_command(bthost, BT_HCI_CMD_RESET, NULL, 0);
 
+	send_command(bthost, BT_HCI_CMD_READ_LOCAL_FEATURES, NULL, 0);
 	send_command(bthost, BT_HCI_CMD_READ_BD_ADDR, NULL, 0);
 }
 
